OC.L10N.register(
    "news",
    {
    "Download" : "Muat turun",
    "Close" : "Tutup",
    "Language" : "Bahasa",
    "by" : "oleh",
    "from" : "dari",
    "Description" : "Keterangan",
    "Refresh" : "Refresh",
    "Web address" : "Alamat sesawang",
    "Folder" : "Folder",
    "Credentials" : "Credentials",
    "Username" : "Nama pengguna",
    "Password" : "Kata laluan",
    "Create" : "Buat",
    "Rename" : "Namakan",
    "Delete" : "Padam",
    "Settings" : "Tetapan",
    "Import" : "Import",
    "Export" : "Export",
    "Help" : "Bantuan",
    "Documentation" : "Dokumentasi"
},
"nplurals=1; plural=0;");
